# 2021-12-08 - Preminted BPT Meta Stable Pool

Deployment of the `StablePhantomPool`, for Meta Stable Pools with preminted BPT of up to 4 tokens.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`StablePhantomPool` ABI](./abi/StablePhantomPool.json)
